@@ -33,8 +33,6 @@ AssetCommand::AssetCommand(const std::shared_ptr<AssetParameterModel> &model, co
     , m_updateView(false)
     , m_stamp(QTime::currentTime())
 {
-    QLocale locale;
-    locale.setNumberOptions(QLocale::OmitGroupSeparator);
     m_name = m_model->data(index, AssetParameterModel::NameRole).toString();
     const QString id = model->getAssetId();
     if (EffectsRepository::get()->exists(id)) {
@@ -43,26 +41,25 @@ AssetCommand::AssetCommand(const std::shared_ptr<AssetParameterModel> &model, co
         setText(i18n("Edit %1", TransitionsRepository::get()->getName(id)));
     }
     QVariant previousVal = m_model->data(index, AssetParameterModel::ValueRole);
-    m_oldValue = previousVal.type() == QVariant::Double ? locale.toString(previousVal.toDouble()) : previousVal.toString();
+    m_oldValue = previousVal.type() == previousVal.toString();
 }
 
 void AssetCommand::undo()
 {
     m_model->setParameter(m_name, m_oldValue, true, m_index);
 }
-// virtual
+
 void AssetCommand::redo()
 {
     m_model->setParameter(m_name, m_value, m_updateView, m_index);
     m_updateView = true;
 }
 
-// virtual
 int AssetCommand::id() const
 {
     return 1;
 }
-// virtual
+
 bool AssetCommand::mergeWith(const QUndoCommand *other)
 {
     if (other->id() != id() || static_cast<const AssetCommand *>(other)->m_index != m_index ||
@@ -82,8 +79,6 @@ AssetMultiCommand::AssetMultiCommand(const std::shared_ptr<AssetParameterModel>
     , m_updateView(false)
     , m_stamp(QTime::currentTime())
 {
-    QLocale locale;
-    locale.setNumberOptions(QLocale::OmitGroupSeparator);
     qDebug()<<"CREATING MULTIPLE COMMAND!!!\nVALUES: "<<m_values;
     m_name = m_model->data(indexes.first(), AssetParameterModel::NameRole).toString();
     const QString id = model->getAssetId();
@@ -94,7 +89,7 @@ AssetMultiCommand::AssetMultiCommand(const std::shared_ptr<AssetParameterModel>
     }
     for (QModelIndex ix : m_indexes) {
         QVariant previousVal = m_model->data(ix, AssetParameterModel::ValueRole);
-        m_oldValues << (previousVal.type() == QVariant::Double ? locale.toString(previousVal.toDouble()) : previousVal.toString());
+        m_oldValues << previousVal.toString();
     }
 }
 
