@@ -41,8 +41,8 @@ BoolParamWidget::BoolParamWidget(std::shared_ptr<AssetParameterModel> model, QMo
     slotRefresh();
 
     // emit the signal of the base class when appropriate
-    connect(this->m_checkBox, &QCheckBox::stateChanged, [this](int) {
-        emit valueChanged(m_index, QString::number(m_checkBox->isChecked()), true); });
+    connect(this->m_checkBox, &QCheckBox::stateChanged, [this](int state) {
+        emit valueChanged(m_index, QString::number(state), true); });
 }
 
 void BoolParamWidget::slotShowComment(bool show)
