@@ -84,7 +84,11 @@ bool TranscodeJob::startJob()
         // insert transcoded filename
         m_transcodeParams.replace(QStringLiteral("%1"), QString("-consumer %1"));
         // Convert param style
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         QStringList params = m_transcodeParams.split(QLatin1Char('-'), QString::SkipEmptyParts);
+#else
+        QStringList params = m_transcodeParams.split(QLatin1Char('-'), Qt::SkipEmptyParts);
+#endif
         QStringList mltParameters;
         for (const QString &s : params) {
             QString t = s.simplified();
