@@ -20,6 +20,7 @@
 
 #include "core.h"
 #include "logger.hpp"
+#include "dialogs/splash.hpp"
 #include <config-kdenlive.h>
 
 #include <mlt++/Mlt.h>
@@ -101,7 +102,7 @@ int main(int argc, char *argv[])
 
     QPixmap pixmap(":/pics/splash-background.png");
     qApp->processEvents(QEventLoop::AllEvents);
-    QSplashScreen splash(pixmap);
+    Splash splash(pixmap);
     qApp->processEvents(QEventLoop::AllEvents);
     splash.showMessage(i18n("Version %1", QString(KDENLIVE_VERSION)), Qt::AlignRight | Qt::AlignBottom, Qt::white);
     splash.show();
@@ -257,8 +258,11 @@ int main(int argc, char *argv[])
     }
     qApp->processEvents(QEventLoop::AllEvents);
     Core::build(!parser.value(QStringLiteral("config")).isEmpty(), parser.value(QStringLiteral("mlt-path")));
+    QObject::connect(pCore.get(), &Core::loadingMessageUpdated, &splash, &Splash::showProgressMessage, Qt::DirectConnection);
+    QObject::connect(pCore.get(), &Core::closeSplash, [&] () {
+        splash.finish(pCore->window());
+    });
     pCore->initGUI(url, clipsToLoad);
-    splash.finish(pCore->window());
     int result = app.exec();
     Core::clean();
 
@@ -276,7 +280,11 @@ int main(int argc, char *argv[])
                 }
             }
         }
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         QStringList progArgs = QString(*argv).split(QLatin1Char(' '), QString::SkipEmptyParts);
+#else
+        QStringList progArgs = QString(*argv).split(QLatin1Char(' '), Qt::SkipEmptyParts);
+#endif
         // Remove app name
         progArgs.takeFirst();
         auto *restart = new QProcess;
