@@ -62,33 +62,6 @@ ClipController::ClipController(const QString &clipId, const std::shared_ptr<Mlt:
     }
     if (m_properties) {
         setProducerProperty(QStringLiteral("kdenlive:id"), m_controllerBinId);
-        m_service = m_properties->get("mlt_service");
-        if (m_service == QLatin1String("qtext")) {
-            // Placeholder clip, find real service
-            QString originalService = m_properties->get("kdenlive:orig_service");
-            if (!originalService.isEmpty()) {
-                m_service = originalService;
-            }
-        }
-        QString proxy = m_properties->get("kdenlive:proxy");
-        QString path = m_properties->get("resource");
-        if (proxy.length() > 2) {
-            if (QFileInfo(path).isRelative()) {
-                path.prepend(pCore->currentDoc()->documentRoot());
-                m_properties->set("resource", path.toUtf8().constData());
-            }
-            // This is a proxy producer, read original url from kdenlive property
-            path = m_properties->get("kdenlive:originalurl");
-            if (QFileInfo(path).isRelative()) {
-                path.prepend(pCore->currentDoc()->documentRoot());
-            }
-            m_usesProxy = true;
-        } else if (m_service != QLatin1String("color") && m_service != QLatin1String("colour") && !path.isEmpty() && QFileInfo(path).isRelative() &&
-                   path != QLatin1String("<producer>")) {
-            path.prepend(pCore->currentDoc()->documentRoot());
-            m_properties->set("resource", path.toUtf8().constData());
-        }
-        m_path = path.isEmpty() ? QString() : QFileInfo(path).absoluteFilePath();
         getInfoForProducer();
         checkAudioVideo();
     } else {
@@ -115,7 +88,6 @@ const std::unique_ptr<AudioStreamInfo> &ClipController::audioInfo() const
 void ClipController::addMasterProducer(const std::shared_ptr<Mlt::Producer> &producer)
 {
     qDebug() << "################### ClipController::addmasterproducer";
-    QString documentRoot = pCore->currentDoc()->documentRoot();
     m_masterProducer = producer;
     m_properties = new Mlt::Properties(m_masterProducer->get_properties());
     m_producerLock.unlock();
@@ -144,21 +116,6 @@ void ClipController::addMasterProducer(const std::shared_ptr<Mlt::Producer> &pro
     } else {
         checkAudioVideo();
         setProducerProperty(QStringLiteral("kdenlive:id"), m_controllerBinId);
-        QString proxy = m_properties->get("kdenlive:proxy");
-        m_service = m_properties->get("mlt_service");
-        QString path = m_properties->get("resource");
-        m_usesProxy = false;
-        if (proxy.length() > 2) {
-            // This is a proxy producer, read original url from kdenlive property
-            path = m_properties->get("kdenlive:originalurl");
-            if (QFileInfo(path).isRelative()) {
-                path.prepend(documentRoot);
-            }
-            m_usesProxy = true;
-        } else if (m_service != QLatin1String("color") && m_service != QLatin1String("colour") && !path.isEmpty() && QFileInfo(path).isRelative()) {
-            path.prepend(documentRoot);
-        }
-        m_path = path.isEmpty() ? QString() : QFileInfo(path).absoluteFilePath();
         getInfoForProducer();
         emitProducerChanged(m_controllerBinId, producer);
     }
@@ -215,6 +172,37 @@ void ClipController::getProducerXML(QDomDocument &document, bool includeMeta, bo
 void ClipController::getInfoForProducer()
 {
     QReadLocker lock(&m_producerLock);
+    m_service = m_properties->get("mlt_service");
+    if (m_service == QLatin1String("qtext")) {
+        // Placeholder clip, find real service
+        QString originalService = m_properties->get("kdenlive:orig_service");
+        if (!originalService.isEmpty()) {
+            m_service = originalService;
+        }
+    }
+    QString proxy = m_properties->get("kdenlive:proxy");
+    QString path = m_properties->get("resource");
+    if (proxy.length() > 2) {
+        if (QFileInfo(path).isRelative()) {
+            path.prepend(pCore->currentDoc()->documentRoot());
+            m_properties->set("resource", path.toUtf8().constData());
+        }
+        // This is a proxy producer, read original url from kdenlive property
+        path = m_properties->get("kdenlive:originalurl");
+        if (QFileInfo(path).isRelative()) {
+            path.prepend(pCore->currentDoc()->documentRoot());
+        }
+        m_usesProxy = true;
+    } else if (m_service != QLatin1String("color") && m_service != QLatin1String("colour") && !path.isEmpty() && QFileInfo(path).isRelative() &&
+                   path != QLatin1String("<producer>")) {
+        path.prepend(pCore->currentDoc()->documentRoot());
+        m_properties->set("resource", path.toUtf8().constData());
+    }
+    m_path = path.isEmpty() ? QString() : QFileInfo(path).absoluteFilePath();
+    QString origurl = m_properties->get("kdenlive:originalurl");
+    if (!origurl.isEmpty()) {
+        m_properties->set("kdenlive:originalurl", m_path.toUtf8().constData());
+    }
     date = QFileInfo(m_path).lastModified();
     m_videoIndex = -1;
     int audioIndex = -1;
@@ -247,6 +235,8 @@ void ClipController::getInfoForProducer()
         }
     } else if (m_service == QLatin1String("colour") || m_service == QLatin1String("color")) {
         m_clipType = ClipType::Color;
+        // Required for faster compositing
+        m_masterProducer->set("mlt_image_format", "rgb24");
         m_hasLimitedDuration = false;
     } else if (m_service == QLatin1String("kdenlivetitle")) {
         if (!m_path.isEmpty()) {
@@ -273,6 +263,13 @@ void ClipController::getInfoForProducer()
     }
     if (audioIndex > -1 || m_clipType == ClipType::Playlist) {
         m_audioInfo = std::make_unique<AudioStreamInfo>(m_masterProducer, audioIndex);
+        // Load stream effects
+        for (int stream : m_audioInfo->streams().keys()) {
+            QString streamEffect = m_properties->get(QString("kdenlive:stream:%1").arg(stream).toUtf8().constData());
+            if (!streamEffect.isEmpty()) {
+                m_streamEffects.insert(stream, streamEffect.split(QChar('#')));
+            }
+        }
     }
 
     if (!m_hasLimitedDuration) {
@@ -319,10 +316,10 @@ const char *ClipController::getPassPropertiesList(bool passLength)
 {
     if (!passLength) {
         return "kdenlive:proxy,kdenlive:originalurl,force_aspect_num,force_aspect_den,force_aspect_ratio,force_fps,force_progressive,force_tff,threads,force_"
-               "colorspace,set.force_full_luma,file_hash,autorotate,xmldata,video_index,audio_index,set.test_image,set.test_audio";
+               "colorspace,set.force_full_luma,file_hash,autorotate,disable_exif,xmldata,video_index,audio_index,set.test_image,set.test_audio";
     }
     return "kdenlive:proxy,kdenlive:originalurl,force_aspect_num,force_aspect_den,force_aspect_ratio,force_fps,force_progressive,force_tff,threads,force_"
-           "colorspace,set.force_full_luma,templatetext,file_hash,autorotate,xmldata,length,video_index,audio_index,set.test_image,set.test_audio";
+           "colorspace,set.force_full_luma,templatetext,file_hash,autorotate,disable_exif,xmldata,length,video_index,audio_index,set.test_image,set.test_audio";
 }
 
 QMap<QString, QString> ClipController::getPropertiesFromPrefix(const QString &prefix, bool withPrefix)
@@ -364,13 +361,13 @@ void ClipController::updateProducer(const std::shared_ptr<Mlt::Producer> &produc
     *m_masterProducer = producer.get();
     m_properties = new Mlt::Properties(m_masterProducer->get_properties());
     m_producerLock.unlock();
-    setProducerProperty(QStringLiteral("kdenlive:id"), m_controllerBinId);
-    checkAudioVideo();
-    // Pass properties from previous producer
-    m_properties->pass_list(passProperties, passList);
     if (!m_masterProducer->is_valid()) {
         qCDebug(KDENLIVE_LOG) << "// WARNING, USING INVALID PRODUCER";
     } else {
+        // Pass properties from previous producer
+        m_properties->pass_list(passProperties, passList);
+        checkAudioVideo();
+        setProducerProperty(QStringLiteral("kdenlive:id"), m_controllerBinId);
         m_effectStack->resetService(m_masterProducer);
         emitProducerChanged(m_controllerBinId, producer);
         // URL and name should not be updated otherwise when proxying a clip we cannot find back the original url
@@ -1039,7 +1036,7 @@ void ClipController::refreshAudioInfo()
     }
 }
 
-QList <int> ClipController::audioStreams() const
+QMap <int, QString> ClipController::audioStreams() const
 {
     if (m_audioInfo) {
         return m_audioInfo->streams();
@@ -1047,6 +1044,14 @@ QList <int> ClipController::audioStreams() const
     return {};
 }
 
+QMap <int, QString> ClipController::activeStreams() const
+{
+    if (m_audioInfo) {
+        return m_audioInfo->activeStreams();
+    }
+    return {};
+}
+
 int ClipController::audioStreamsCount() const
 {
     if (m_audioInfo) {
@@ -1054,3 +1059,4 @@ int ClipController::audioStreamsCount() const
     }
     return 0;
 }
+
